

=========================
PrismStudio Documentation
=========================

.. role:: raw-math(raw)
    :format: latex html

| Date: December 16th, 2024 Version: 1.7.0
| Welcome to PrismStudio Documentation!

.. toctree::
  :maxdepth: 3
  :hidden:

  Getting Started <1_getstarted/index>
  3_contentguide/index
  4_releasenote/index


.. _badges-buttons:

.. grid::

    .. grid-item-card::

        .. image:: _static/getstarted.svg
          :alt: Getting Started
          :class: only-dark main-background

        .. image:: _static/getstarted.svg
          :alt: Getting Started
          :class: only-light main-background

        **Getting Started**

        ^^^^^^^^^^^^^^
        New to PrismStudio? Check out the getting started guide. It contains a 10 minutes introduction to PrismStudio's basic fetures.
        ++++++++++++++
        .. button-link:: 1_getstarted/index.html
            :ref-type: ref
            :color: muted
            :shadow:

            To the getting started guide


    .. grid-item-card::

        .. image:: _static/apiref.svg
          :alt: Reference
          :class: only-dark main-background

        .. image:: _static/apiref.svg
          :alt: Reference
          :class: only-light main-background

        **Content Guide**

        ^^^^^^^^^^^^^^
        The content guide contains a detailed description of the PrismStudio API. The reference describes methods and parameters can be used. It assumes that you have an understanding of the key concepts.
        ++++++++++++++
        .. button-link:: 3_contentguide/index.html
            :ref-type: ref
            :color: muted
            :align: center
            :shadow:

            To the content guide


.. grid::

    .. grid-item-card::

        .. image:: _static/releasenote.svg
          :alt: Release Note
          :class: only-dark main-background

        .. image:: _static/releasenote.svg
          :alt: Release Note
          :class: only-light main-background


        **Release Note**
        ^^^^^^^^^^^^^^
        Release note includes all changing details of each version of PrismStudio deployment. Discover newly released features or bug fixes!
        ++++++++++++++
        .. button-link:: 4_releasenote/index.html
            :ref-type: ref
            :color: muted
            :shadow:

            To the release notes

